@@ -21,6 +21,8 @@ from .AEC_EVALUATION.ERLE_ETSIMATION import cal_erle
 from .FUNCTION.audioFunction import isSlience,audioFormat
 from .AEC_MOS.aecmos import cal_aec_mos
 from .MOS_INFER.run_predict import cal_mos_infer
+from .MOS_INFER.NISQA_model import *
+from .MOS_INFER.NISQA_lib import *
 from operator import methodcaller
 from .computeAudioQuality.mainProcess import computeAudioQuality
 
