@@ -40,7 +40,33 @@ def get_data_of_ctypes_(inWaveFile=None):
     wavf.close()
     return  datastruct,refsamplerate,refframeCount
 
+def get_none_data_of_ctypes_(dataLength=0):
 
+    data =  np.array([0.0 for _ in range(dataLength)])
+    data = data.astype(np.float64)
+
+    outStruct = emxArray_real_T()
+    #outStruct = create_string_buffer(20)
+    outStruct.pdata =  (c_double * dataLength)(*data)
+    outStruct.psize = (c_int * 1)(*[dataLength])
+    outStruct.allocSize = dataLength
+    outStruct.NumDimensions = 1
+    outStruct.canFreeData = 1
+    return outStruct
+
+def write_ctypes_data_2_file_(outFile,outStruct,refsamplerate):
+    outf = wave.open(outFile, 'wb')
+    outf.setnchannels(1)
+    outf.setsampwidth(2)
+    outf.setframerate(refsamplerate)
+    # 将wav_data转换为二进制数据写入文件
+    outlist = []
+    for a in range(outStruct.psize[0]):
+        outlist.append(int(outStruct.pdata[a]))
+    outarray = np.array(outlist)
+    outarray = outarray.astype(np.int16)
+    outf.writeframes(bytes(outarray))
+    outf.close()
 constMosResult = {'delay':'No Result','mos':'0.0','Speech Level Gain':'','Noise Level Gain':''}
 
 class commondata():
