@@ -28,9 +28,14 @@ from AGC_EVALUATION.CAL_MUSIC_STABILITY import cal_music_stablility
 from AGC_EVALUATION.CAL_DELAY import cal_DELAY
 from AEC_EVALUATION.MATCH_AEC import MATCH_AEC
 from AEC_EVALUATION.ERLE_ETSIMATION import cal_erle
+from AEC_MOS.aecmos import cal_aec_mos
+from MOS_INFER.run_predict import cal_mos_infer
 from FUNCTION.audioFunction import isSlience,audioFormat
 
-allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE','ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT']
+allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR',
+              'SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE',
+              'ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT',
+              'MATCHAEC','ERLE','AECMOS','AIMOS']
 
 
 class computeAudioQuality():
@@ -51,8 +56,10 @@ class computeAudioQuality():
         self.mertic = kwargs['metrics']
         self.testFile = kwargs['testFile']
         self.refFile = kwargs['refFile']
+        self.micFile = kwargs['micFile']
         self.cleFile = kwargs['cleFile']
         self.noiseFile = kwargs['noiseFile']
+        self.caliFile = kwargs['aecCaliFile']
         self.outFile = kwargs['outFile']
         self.samplerate = kwargs['samplerate']
         self.bitwidth = kwargs['bitwidth']
@@ -62,6 +69,9 @@ class computeAudioQuality():
         self.maxComNLevel = kwargs['maxComNLevel']
         self.speechPauseLevel = kwargs['speechPauseLevel']
         self.audioType = kwargs["audioType"]
+        self.aecStartPoint = kwargs['aecStartPoint']
+        self.aecScenario = kwargs['aecScenario']
+        self.aecTargetType = kwargs["aecTargetType"]
         #maxComNLevel=c_double(-48.0),speechPauseLevel=c_double(-35.0)
 
     def __chcek_valid(self):
@@ -205,6 +215,14 @@ class computeAudioQuality():
         return cal_sti(pcm2wav(self.refFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate))
         pass
 
+    def SII(self):
+        """
+        Returns
+        -------
+
+        """
+        pass
+
     def PEAQ(self):
         """
         # wav输入
@@ -216,7 +234,7 @@ class computeAudioQuality():
             #TODO 采样率
             pass
         #TODO 计算peaq
-        return cal_peaq()
+        return cal_peaq(pcm2wav(self.refFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate))
         pass
 
     def SDR(self):
@@ -267,9 +285,19 @@ class computeAudioQuality():
         return match_sig(pcm2wav(self.refFile,sample_rate=self.samplerate), pcm2wav(self.testFile,sample_rate=self.samplerate), self.outFile,self.audioType)
 
     def LOUDNESS(self):
+        """
+        Returns
+        -------
+
+        """
         pass
 
     def __cal_sii__(self):
+        '''
+        Returns
+        -------
+
+        '''
         #return cal_sii()
         pass
 
@@ -312,6 +340,55 @@ class computeAudioQuality():
         return cal_DELAY(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
                              testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
 
+    def AECMOS(self):
+        """
+        Returns
+        -------
+
+        """
+        if self.refFile is None or self.micFile is None or self.testFile is None:
+            raise EOFError('lack of inputfiles!')
+        if self.__check_format(self.refFile) != self.__check_format(self.micFile) or \
+            self.__check_format(self.micFile) != self.__check_format(self.testFile):
+            raise TypeError('there are different parametre in inputfiles!')
+        return cal_aec_mos(pcm2wav(self.refFile,sample_rate=self.samplerate),pcm2wav(self.micFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate),scenario=self.aecScenario,startPoint=self.aecStartPoint,SAMPLE_RATE=self.samplerate)
+
+    def AIMOS(self):
+        """
+        Returns
+        -------
+
+        """
+        if self.testFile is None:
+            raise EOFError('lack of inputfiles!')
+        finalName = pcm2wav(self.testFile,sample_rate=self.samplerate)
+        return cal_mos_infer(finalName)
+
+    def ELRE(self):
+        """
+        Returns
+        -------
+
+        """
+        if self.refFile is None or self.micFile is None or self.testFile is None:
+            raise EOFError('lack of inputfiles!')
+        if self.__check_format(self.refFile) != self.__check_format(self.micFile) or \
+            self.__check_format(self.micFile) != self.__check_format(self.testFile):
+            raise TypeError('there are different parametre in inputfiles!')
+        return cal_erle(pcm2wav(self.refFile,sample_rate=self.samplerate),pcm2wav(self.micFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate),targetType=self.aecTargetType)
+
+    def MATCHAEC(self):
+        """
+        Returns
+        -------
+
+        """
+        if self.caliFile is None or self.micFile is None or self.testFile is None:
+            raise EOFError('lack of inputfiles!')
+        if self.__check_format(self.caliFile) != self.__check_format(self.micFile) or \
+            self.__check_format(self.caliFile) != self.__check_format(self.testFile):
+            raise TypeError('there are different parametre in inputfiles!')
+        return MATCH_AEC(pcm2wav(self.micFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate),pcm2wav(self.caliFile,sample_rate=self.samplerate),self.outFile,targetType=self.aecTargetType)
 
     def SLIENCE(self):
         """
@@ -319,6 +396,8 @@ class computeAudioQuality():
         -------
 
         """
+        if self.testFile is None:
+            raise EOFError('lack of inputfiles!')
         return isSlience(self.testFile)
 
     def FORMAT(self):
@@ -327,4 +406,6 @@ class computeAudioQuality():
         -------
 
         """
+        if self.testFile is None:
+            raise EOFError('lack of inputfiles!')
         return audioFormat(self.testFile)
\ No newline at end of file
